@@ -125,13 +125,5 @@ class DeHyperPol(Recording):
         self.amp2_rel = 100.0 * self.amp2 / amp_threshold
         self.hypamp_rel = 100.0 * self.hypamp / amp_threshold
 
-    def in_target(self, target, tolerance):
-        """Returns a boolean. True if the amplitude of the eCode is close to
-        target and False otherwise."""
-        if numpy.abs(target - self.amp_rel) < tolerance:
-            return True
-        else:
-            return False
-
     def get_plot_amplitude_title(self):
         return " ({:.01f}%/{:.01f}%)".format(self.amp_rel, self.amp2_rel)
