@@ -309,7 +309,10 @@ def compute_rheobase(
 
 
 def _build_protocols(
-    targets, global_rheobase, protocol_mode, efel_settings=None
+    targets,
+    global_rheobase,
+    protocol_mode,
+    efel_settings=None
 ):
     """Build a list of Protocols that matches the expected targets"""
 
@@ -355,6 +358,7 @@ def _build_protocols(
 def group_efeatures(
     cells,
     targets,
+    absolute_amplitude=False,
     use_global_rheobase=True,
     protocol_mode='mean',
     efel_settings=None
@@ -380,6 +384,9 @@ def group_efeatures(
                     'Threshold': -10.
                 }
             }]
+        absolute_amplitude (bool): if True, will use the absolute amplitude
+            instead of the relative amplitudes of the recordings when checking
+            if a recording has to be used for a given target.
         use_global_rheobase (bool): As the final amplitude of a target is the
             mean of the amplitude of the cells, a global rheobase can be used
             to avoid issues when a cell matches a target but not another one.
@@ -399,7 +406,7 @@ def group_efeatures(
         efel_settings = {}
 
     global_rheobase = None
-    if use_global_rheobase:
+    if use_global_rheobase and not absolute_amplitude:
         global_rheobase = numpy.nanmean(
             [c.rheobase for c in cells if c.rheobase is not None]
         )
@@ -408,13 +415,13 @@ def group_efeatures(
         targets,
         global_rheobase=global_rheobase,
         protocol_mode=protocol_mode,
-        efel_settings=efel_settings
+        efel_settings=efel_settings,
     )
 
     for protocol in protocols:
         for cell in cells:
 
-            if cell.rheobase is None:
+            if cell.rheobase is None and not absolute_amplitude:
                 continue
 
             for recording in cell.get_recordings_by_protocol_name(
@@ -422,15 +429,16 @@ def group_efeatures(
             ):
 
                 if recording.in_target(
-                        protocol.amplitude,
-                        protocol.tolerance
+                    protocol.amplitude,
+                    protocol.tolerance,
+                    absolute_amplitude
                 ):
                     protocol.append(recording)
 
     return protocols
 
 
-def _build_current_dict(cells):
+def _build_current_dict(cells, default_std_value):
     """
     Compute the mean and standard deviation of the holding and threshold
     currents.
@@ -448,14 +456,22 @@ def _build_current_dict(cells):
         if cell.rheobase is not None:
             threshold[cell.name] = cell.rheobase
 
+    std_holding = numpy.nanstd(list(holding.values()))
+    if std_holding == 0:
+        std_holding = default_std_value
+
+    std_threshold = numpy.nanstd(list(threshold.values()))
+    if std_threshold == 0:
+        std_threshold = default_std_value
+
     currents = {
         "holding_current": [
             numpy.nanmean(list(holding.values())),
-            numpy.nanstd(list(holding.values())),
+            std_holding,
         ],
         "threshold_current": [
             numpy.nanmean(list(threshold.values())),
-            numpy.nanstd(list(threshold.values())),
+            std_threshold,
         ],
         "all_holding_current": holding,
         "all_threshold_current": threshold,
@@ -471,6 +487,7 @@ def create_feature_protocol_files(
     threshold_nvalue_save=1,
     write_files=True,
     save_files_used=False,
+    default_std_value=1e-3
 ):
     """
     Save the efeatures and protocols for each protocol/target combo
@@ -488,6 +505,8 @@ def create_feature_protocol_files(
         save_files_used (bool): if True, the name of the recording files used
             in the computation of the features will be added to the
             efeatures.
+        default_std_value (float): default value used to replace the standard
+            deviation if the standard deviation is 0.
 
     Returns:
         feat (dict)
@@ -515,7 +534,7 @@ def create_feature_protocol_files(
                 )
                 continue
 
-            tmp_feat.append(target.as_legacy_dict(save_files_used))
+            tmp_feat.append(target.as_dict(save_files_used, default_std_value))
 
         if not tmp_feat:
             logger.warning(
@@ -528,7 +547,7 @@ def create_feature_protocol_files(
         out_stimuli[stimname] = protocol.as_dict()
 
     # Compute the mean and std of holding and threshold currents
-    currents = _build_current_dict(cells)
+    currents = _build_current_dict(cells, default_std_value)
 
     if write_files:
 
@@ -659,6 +678,7 @@ def _extract_with_targets(
     files_metadata,
     targets=None,
     protocols_rheobase=None,
+    absolute_amplitude=False,
     recording_reader=None,
     map_function=map,
     low_memory_mode=False,
@@ -683,16 +703,18 @@ def _extract_with_targets(
             files_metadata, recording_reader, targets, efel_settings
         )
 
-    compute_rheobase(
-        cells,
-        protocols_rheobase=protocols_rheobase,
-        rheobase_strategy=rheobase_strategy,
-        rheobase_settings=rheobase_settings
-    )
+    if not absolute_amplitude:
+        compute_rheobase(
+            cells,
+            protocols_rheobase=protocols_rheobase,
+            rheobase_strategy=rheobase_strategy,
+            rheobase_settings=rheobase_settings
+        )
 
     protocols = group_efeatures(
         cells,
         targets,
+        absolute_amplitude=absolute_amplitude,
         use_global_rheobase=True,
         protocol_mode=protocol_mode,
         efel_settings=efel_settings
@@ -772,7 +794,8 @@ def extract_efeatures_per_cell(
     targets,
     protocol_mode,
     threshold_nvalue_save,
-    write_files
+    write_files,
+    default_std_value=1e-3
 ):
 
     for cell_name in files_metadata:
@@ -797,6 +820,7 @@ def extract_efeatures_per_cell(
                 output_directory=cell_directory,
                 threshold_nvalue_save=threshold_nvalue_save,
                 write_files=write_files,
+                default_std_value=default_std_value
             )
 
 
@@ -806,6 +830,7 @@ def extract_efeatures(
     targets=None,
     threshold_nvalue_save=1,
     protocols_rheobase=None,
+    absolute_amplitude=False,
     recording_reader=None,
     map_function=map,
     write_files=False,
@@ -818,6 +843,7 @@ def extract_efeatures(
     rheobase_settings=None,
     auto_targets=None,
     pickle_cells=False,
+    default_std_value=1e-3
 ):
     """
     Extract efeatures.
@@ -839,9 +865,11 @@ def extract_efeatures(
             need to be present in the file metadata of different protocols if
             the path contains data coming from different stimuli (eg: for NWB).
         targets (list): define the efeatures to extract as well as which
-            protocols and current amplitude (expressed in % of the rheobase)
-            they should be extracted. If targets are not provided, automatic
-            targets will be used. Of the form:
+            protocols and current amplitude (expressed either in % of the
+            rheobase if absolute_amplitude if False or in nA if
+            absolute_amplitude is True) they should be extracted.
+            If targets are not provided, automatic targets will be used.
+            Of the form:
             [{
                 "efeature": "AP_amplitude",
                 "protocol": "IDRest",
@@ -857,6 +885,9 @@ def extract_efeatures(
             an efeatures to be averaged and returned in the output.
         protocols_rheobase (list): names of the protocols that will be
             used to compute the rheobase of the cells. E.g: ['IDthresh'].
+        absolute_amplitude (bool): if True, will use the absolute amplitude
+            instead of the relative amplitudes of the recordings when checking
+            if a recording has to be used for a given target.
         recording_reader (function): custom recording reader function. It's
             inner working has to match the metadata entered in files_metadata.
         map_function (function): Function used to map (parallelize) the
@@ -891,6 +922,8 @@ def extract_efeatures(
             computation function.
         auto_targets (list of AutoTarget): targets with more flexible goals.
         pickle_cells (bool): if True, the cells object will be saved as a pickle file.
+        default_std_value (float): default value used to replace the standard
+            deviation if the standard deviation is 0.
     """
 
     if not files_metadata:
@@ -902,7 +935,7 @@ def extract_efeatures(
         )
         efel_settings = DEFAULT_EFEL_SETTINGS.copy()
 
-    if protocols_rheobase is None:
+    if protocols_rheobase is None and not absolute_amplitude:
         logger.warning(
             "protocols_rheobase is None. Default protocol names will be used"
         )
@@ -925,7 +958,10 @@ def extract_efeatures(
     if targets is not None and auto_targets is not None:
         raise Exception("Cannot specify both targets and auto_targets.")
 
-    if targets is None or auto_targets is not None:
+    if (
+        not absolute_amplitude and
+        (targets is None or auto_targets is not None)
+    ):
         cells, protocols, targets = _extract_auto_targets(
             files_metadata,
             protocols_rheobase,
@@ -942,6 +978,7 @@ def extract_efeatures(
             files_metadata,
             targets,
             protocols_rheobase,
+            absolute_amplitude,
             recording_reader,
             map_function,
             low_memory_mode,
@@ -957,6 +994,7 @@ def extract_efeatures(
         output_directory=output_directory,
         threshold_nvalue_save=threshold_nvalue_save,
         write_files=write_files,
+        default_std_value=default_std_value
     )
 
     if pickle_cells:
@@ -977,7 +1015,7 @@ def extract_efeatures(
             targets,
             protocol_mode,
             threshold_nvalue_save,
-            write_files
+            write_files,
         )
 
     if not efeatures or not protocol_definitions:
